/**
 * @prettier
 */
/// <reference types="koa__cors" />
/// <reference types="koa__router" />
/// <reference types="node" />
/// <reference types="node" />
import Cors from "@koa/cors";
import Koa, { Middleware } from "koa";
import Router from "@koa/router";
import { Server } from "http";
import { KoaBodyMiddlewareOptions } from "koa-body/lib/types";
import { AddressInfo } from "node:net";
type Enumerate<N extends number, Acc extends number[] = []> = Acc["length"] extends N ? Acc[number] : Enumerate<N, [...Acc, Acc["length"]]>;
type IntRange<F extends number, T extends number> = F extends T ? F : Exclude<Enumerate<T>, Enumerate<F>> extends never ? never : Exclude<Enumerate<T>, Enumerate<F>> | T;
export type StatusCode1xx = IntRange<100, 199>;
export type StatusCode2xx = IntRange<200, 299>;
export type StatusCode3xx = IntRange<300, 399>;
export type StatusCode4xx = IntRange<400, 499>;
export type StatusCode5xx = IntRange<500, 599>;
export type StatusCode = StatusCode1xx | StatusCode2xx | StatusCode3xx | StatusCode4xx | StatusCode5xx;
export declare class KoaRuntimeResponse<Type> {
    private readonly status;
    private _body?;
    constructor(status: number);
    body(body: Type): this;
    unpack(): {
        status: number;
        body: Type | undefined;
    };
}
export type KoaRuntimeResponder<Status extends StatusCode = StatusCode, Type = any> = {
    withStatus: (status: Status) => KoaRuntimeResponse<Type>;
};
export type ServerConfig = {
    /** set to false to disable cors middleware, pass undefined for defaults */
    cors?: false | Cors.Options | undefined;
    /**
     * set to false to disable body parsing middleware, pass undefined for defaults.
     *
     * if disabling, ensure you pass a body parsing middlware that places the parsed
     * body on `ctx.body` for request body processing to work.
     **/
    body?: false | KoaBodyMiddlewareOptions | undefined;
    /**
     * optional array of arbitrary middleware to be mounted before the Router,
     * useful for mounting logging, alternative body parsers, etc
     */
    middleware?: Middleware[];
    /**
     * the router to use, normally obtained by calling the generated `createRouter`
     * function
     */
    router: Router;
    /**
     * the port to listen on, a randomly allocated port will be used if none passed
     */
    port?: number;
};
export declare function startServer({ middleware, cors, body, port, router, }: ServerConfig): Promise<{
    app: Koa;
    server: Server;
    address: AddressInfo;
}>;
export {};
